@@ -30,8 +30,9 @@ import polars as pl
 import pytest
 from databricks.sql.types import Row
 
-from airflow.exceptions import AirflowException, AirflowOptionalProviderFeatureException
+from airflow.exceptions import AirflowOptionalProviderFeatureException
 from airflow.models import Connection
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.common.sql.hooks.handlers import fetch_all_handler
 from airflow.providers.databricks.hooks.databricks_sql import DatabricksSqlHook, create_timeout_thread
 
@@ -39,7 +40,6 @@ TASK_ID = "databricks-sql-operator"
 DEFAULT_CONN_ID = "databricks_default"
 HOST = "xx.cloud.databricks.com"
 HOST_WITH_SCHEME = "https://xx.cloud.databricks.com"
-PORT = 443
 TOKEN = "token"
 HTTP_PATH = "sql/protocolv1/o/1234567890123456/0123-456789-abcd123"
 SCHEMA = "test_schema"
@@ -112,38 +112,36 @@ def mock_timer():
         yield mock_timer
 
 
-def make_mock_connection():
-    return Connection(
-        conn_id=DEFAULT_CONN_ID,
-        conn_type="databricks",
-        host=HOST,
-        port=PORT,
-        login="token",
-        password=TOKEN,
-    )
-
-
-def test_sqlachemy_url_property(mock_get_conn):
-    mock_get_conn.return_value = make_mock_connection()
+def test_sqlachemy_url_property():
     hook = DatabricksSqlHook(
         databricks_conn_id=DEFAULT_CONN_ID, http_path=HTTP_PATH, catalog=CATALOG, schema=SCHEMA
     )
     url = hook.sqlalchemy_url.render_as_string(hide_password=False)
     expected_url = (
-        f"databricks://token:{TOKEN}@{HOST}:{PORT}?"
+        f"databricks://token:{TOKEN}@{HOST}?"
         f"catalog={CATALOG}&http_path={quote_plus(HTTP_PATH)}&schema={SCHEMA}"
     )
     assert url == expected_url
 
 
-def test_get_uri(mock_get_conn):
-    mock_get_conn.return_value = make_mock_connection()
+def test_get_sqlalchemy_engine():
+    hook = DatabricksSqlHook(
+        databricks_conn_id=DEFAULT_CONN_ID, http_path=HTTP_PATH, catalog=CATALOG, schema=SCHEMA
+    )
+    engine = hook.get_sqlalchemy_engine()
+    assert engine.url.render_as_string(hide_password=False) == (
+        f"databricks://token:{TOKEN}@{HOST}?"
+        f"catalog={CATALOG}&http_path={quote_plus(HTTP_PATH)}&schema={SCHEMA}"
+    )
+
+
+def test_get_uri():
     hook = DatabricksSqlHook(
         databricks_conn_id=DEFAULT_CONN_ID, http_path=HTTP_PATH, catalog=CATALOG, schema=SCHEMA
     )
     uri = hook.get_uri()
     expected_uri = (
-        f"databricks://token:{TOKEN}@{HOST}:{PORT}?"
+        f"databricks://token:{TOKEN}@{HOST}?"
         f"catalog={CATALOG}&http_path={quote_plus(HTTP_PATH)}&schema={SCHEMA}"
     )
     assert uri == expected_uri
@@ -158,8 +156,17 @@ SerializableRow = namedtuple("Row", ["id", "value"])  # type: ignore[name-match]
 
 
 @pytest.mark.parametrize(
-    "return_last, split_statements, sql, execution_timeout, cursor_calls,"
-    "cursor_descriptions, cursor_results, hook_descriptions, hook_results, ",
+    (
+        "return_last",
+        "split_statements",
+        "sql",
+        "execution_timeout",
+        "cursor_calls",
+        "cursor_descriptions",
+        "cursor_results",
+        "hook_descriptions",
+        "hook_results",
+    ),
     [
         pytest.param(
             True,
@@ -376,13 +383,12 @@ def test_query(
     ],
 )
 def test_no_query(databricks_hook, empty_statement):
-    with pytest.raises(ValueError) as err:
+    with pytest.raises(ValueError, match="List of SQL statements is empty"):
         databricks_hook.run(sql=empty_statement)
-    assert err.value.args[0] == "List of SQL statements is empty"
 
 
 @pytest.mark.parametrize(
-    "row_objects, fields_names",
+    ("row_objects", "fields_names"),
     [
         pytest.param(Row("count(1)")(9714), ("_0",)),
         pytest.param(Row("1//@:()")("data"), ("_0",)),
@@ -401,7 +407,7 @@ def test_incorrect_column_names(row_objects, fields_names):
 
 
 @pytest.mark.parametrize(
-    "sql, execution_timeout, cursor_descriptions, cursor_results",
+    ("sql", "execution_timeout", "cursor_descriptions", "cursor_results"),
     [
         (
             "select * from test.test",
@@ -564,7 +570,7 @@ def test_get_openlineage_database_specific_lineage_with_old_openlineage_provider
     hook.get_openlineage_database_info = lambda x: mock.MagicMock(authority="auth", scheme="scheme")
 
     expected_err = (
-        "OpenLineage provider version `1.99.0` is lower than required `2.3.0`, "
+        "OpenLineage provider version `1.99.0` is lower than required `2.5.0`, "
         "skipping function `emit_openlineage_events_for_databricks_queries` execution"
     )
     with pytest.raises(AirflowOptionalProviderFeatureException, match=expected_err):
@@ -572,7 +578,7 @@ def test_get_openlineage_database_specific_lineage_with_old_openlineage_provider
 
 
 @pytest.mark.parametrize(
-    "df_type, df_class, description",
+    ("df_type", "df_class", "description"),
     [
         pytest.param("pandas", pd.DataFrame, [(("col",))], id="pandas-dataframe"),
         pytest.param(
